/********************************************************************************
** Form generated from reading UI file 'MainForm.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINFORM_H
#define UI_MAINFORM_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenu>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qwt_plot.h"

QT_BEGIN_NAMESPACE

class Ui_mainForm
{
public:
    QAction *actionExport_to_NS1;
    QAction *actionExit;
    QAction *actionSSID;
    QAction *actionChannel;
    QAction *actionMAC;
    QAction *actionMode;
    QAction *actionSecurity;
    QAction *actionPrivacy;
    QAction *actionCipher;
    QAction *actionFrequency;
    QAction *actionQuality;
    QAction *actionSignal;
    QAction *actionBW;
    QAction *actionVendor;
    QAction *actionFirst;
    QAction *actionLast;
    QAction *actionType;
    QAction *actionAbout;
    QAction *actionCenChan;
    QAction *actionMin_Signal;
    QAction *actionMax_Signal;
    QAction *actionFirst_Seen;
    QAction *actionLast_Seen;
    QAction *actionPlot;
    QAction *actionPrefs;
    QAction *actionProtocol;
    QWidget *centralwidget;
    QVBoxLayout *verticalLayout;
    QFrame *buttonFrame;
    QFormLayout *formLayout;
    QGridLayout *gridLayout;
    QSlider *napTimeSlider;
    QLabel *napTimeLbl;
    QLabel *statusLbl;
    QLabel *graphLbl;
    QHBoxLayout *horizontalLayout;
    QPushButton *allBtn;
    QPushButton *noneBtn;
    QLabel *statusTxt;
    QPushButton *runBtn;
    QLabel *runLbl;
    QLabel *interfaceLbl;
    QComboBox *interfaceCbx;
    QLabel *linssidLogoMainframe;
    QSplitter *splitter;
    QTableWidget *mainTableWidget;
    QTabWidget *mainTabWgt;
    QWidget *timePlotTab;
    QVBoxLayout *verticalLayout_4;
    QwtPlot *timePlot;
    QWidget *chan24Tab;
    QVBoxLayout *verticalLayout_2;
    QwtPlot *chan24Plot;
    QWidget *chan5Tab;
    QVBoxLayout *verticalLayout_3;
    QwtPlot *chan5Plot;
    QMenuBar *menubar;
    QMenu *menuFile;
    QMenu *menuView;
    QMenu *menuHelp;
    QStatusBar *statusbar;

    void setupUi(QMainWindow *mainForm)
    {
        if (mainForm->objectName().isEmpty())
            mainForm->setObjectName(QString::fromUtf8("mainForm"));
        mainForm->resize(759, 561);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mainForm->sizePolicy().hasHeightForWidth());
        mainForm->setSizePolicy(sizePolicy);
        QIcon icon;
        icon.addFile(QString::fromUtf8("../../../../../../../usr/share/pixmaps/linssid.png"), QSize(), QIcon::Normal, QIcon::Off);
        mainForm->setWindowIcon(icon);
        actionExport_to_NS1 = new QAction(mainForm);
        actionExport_to_NS1->setObjectName(QString::fromUtf8("actionExport_to_NS1"));
        actionExport_to_NS1->setVisible(false);
        actionExit = new QAction(mainForm);
        actionExit->setObjectName(QString::fromUtf8("actionExit"));
        actionSSID = new QAction(mainForm);
        actionSSID->setObjectName(QString::fromUtf8("actionSSID"));
        actionSSID->setCheckable(true);
        actionSSID->setChecked(true);
        actionSSID->setEnabled(true);
        actionChannel = new QAction(mainForm);
        actionChannel->setObjectName(QString::fromUtf8("actionChannel"));
        actionChannel->setCheckable(true);
        actionChannel->setChecked(true);
        actionMAC = new QAction(mainForm);
        actionMAC->setObjectName(QString::fromUtf8("actionMAC"));
        actionMAC->setCheckable(true);
        actionMAC->setChecked(true);
        actionMode = new QAction(mainForm);
        actionMode->setObjectName(QString::fromUtf8("actionMode"));
        actionMode->setCheckable(true);
        actionMode->setChecked(false);
        actionSecurity = new QAction(mainForm);
        actionSecurity->setObjectName(QString::fromUtf8("actionSecurity"));
        actionSecurity->setCheckable(true);
        actionSecurity->setChecked(false);
        actionPrivacy = new QAction(mainForm);
        actionPrivacy->setObjectName(QString::fromUtf8("actionPrivacy"));
        actionPrivacy->setCheckable(true);
        actionPrivacy->setChecked(true);
        actionCipher = new QAction(mainForm);
        actionCipher->setObjectName(QString::fromUtf8("actionCipher"));
        actionCipher->setCheckable(true);
        actionCipher->setChecked(true);
        actionFrequency = new QAction(mainForm);
        actionFrequency->setObjectName(QString::fromUtf8("actionFrequency"));
        actionFrequency->setCheckable(true);
        actionQuality = new QAction(mainForm);
        actionQuality->setObjectName(QString::fromUtf8("actionQuality"));
        actionQuality->setCheckable(true);
        actionQuality->setChecked(false);
        actionSignal = new QAction(mainForm);
        actionSignal->setObjectName(QString::fromUtf8("actionSignal"));
        actionSignal->setCheckable(true);
        actionSignal->setChecked(true);
        actionBW = new QAction(mainForm);
        actionBW->setObjectName(QString::fromUtf8("actionBW"));
        actionBW->setCheckable(true);
        actionVendor = new QAction(mainForm);
        actionVendor->setObjectName(QString::fromUtf8("actionVendor"));
        actionVendor->setCheckable(true);
        actionVendor->setEnabled(true);
        actionVendor->setVisible(true);
        actionFirst = new QAction(mainForm);
        actionFirst->setObjectName(QString::fromUtf8("actionFirst"));
        actionFirst->setCheckable(true);
        actionFirst->setEnabled(true);
        actionFirst->setVisible(true);
        actionLast = new QAction(mainForm);
        actionLast->setObjectName(QString::fromUtf8("actionLast"));
        actionLast->setCheckable(true);
        actionLast->setEnabled(true);
        actionLast->setVisible(true);
        actionType = new QAction(mainForm);
        actionType->setObjectName(QString::fromUtf8("actionType"));
        actionType->setCheckable(true);
        actionType->setEnabled(false);
        actionType->setVisible(false);
        actionAbout = new QAction(mainForm);
        actionAbout->setObjectName(QString::fromUtf8("actionAbout"));
        actionCenChan = new QAction(mainForm);
        actionCenChan->setObjectName(QString::fromUtf8("actionCenChan"));
        actionCenChan->setCheckable(true);
        actionMin_Signal = new QAction(mainForm);
        actionMin_Signal->setObjectName(QString::fromUtf8("actionMin_Signal"));
        actionMin_Signal->setCheckable(true);
        actionMax_Signal = new QAction(mainForm);
        actionMax_Signal->setObjectName(QString::fromUtf8("actionMax_Signal"));
        actionMax_Signal->setCheckable(true);
        actionFirst_Seen = new QAction(mainForm);
        actionFirst_Seen->setObjectName(QString::fromUtf8("actionFirst_Seen"));
        actionFirst_Seen->setCheckable(true);
        actionLast_Seen = new QAction(mainForm);
        actionLast_Seen->setObjectName(QString::fromUtf8("actionLast_Seen"));
        actionLast_Seen->setCheckable(true);
        actionPlot = new QAction(mainForm);
        actionPlot->setObjectName(QString::fromUtf8("actionPlot"));
        actionPlot->setEnabled(false);
        actionPlot->setVisible(false);
        actionPrefs = new QAction(mainForm);
        actionPrefs->setObjectName(QString::fromUtf8("actionPrefs"));
        actionProtocol = new QAction(mainForm);
        actionProtocol->setObjectName(QString::fromUtf8("actionProtocol"));
        actionProtocol->setCheckable(true);
        actionProtocol->setChecked(true);
        centralwidget = new QWidget(mainForm);
        centralwidget->setObjectName(QString::fromUtf8("centralwidget"));
        sizePolicy.setHeightForWidth(centralwidget->sizePolicy().hasHeightForWidth());
        centralwidget->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(centralwidget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        buttonFrame = new QFrame(centralwidget);
        buttonFrame->setObjectName(QString::fromUtf8("buttonFrame"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(buttonFrame->sizePolicy().hasHeightForWidth());
        buttonFrame->setSizePolicy(sizePolicy1);
        buttonFrame->setMinimumSize(QSize(500, 75));
        buttonFrame->setFrameShape(QFrame::StyledPanel);
        buttonFrame->setFrameShadow(QFrame::Sunken);
        formLayout = new QFormLayout(buttonFrame);
        formLayout->setObjectName(QString::fromUtf8("formLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        napTimeSlider = new QSlider(buttonFrame);
        napTimeSlider->setObjectName(QString::fromUtf8("napTimeSlider"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(napTimeSlider->sizePolicy().hasHeightForWidth());
        napTimeSlider->setSizePolicy(sizePolicy2);
        napTimeSlider->setMinimumSize(QSize(120, 20));
        napTimeSlider->setBaseSize(QSize(120, 20));
        napTimeSlider->setMaximum(5);
        napTimeSlider->setPageStep(1);
        napTimeSlider->setSliderPosition(2);
        napTimeSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(napTimeSlider, 0, 11, 1, 1);

        napTimeLbl = new QLabel(buttonFrame);
        napTimeLbl->setObjectName(QString::fromUtf8("napTimeLbl"));
        napTimeLbl->setMinimumSize(QSize(100, 0));
        napTimeLbl->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(napTimeLbl, 1, 11, 1, 1);

        statusLbl = new QLabel(buttonFrame);
        statusLbl->setObjectName(QString::fromUtf8("statusLbl"));
        sizePolicy1.setHeightForWidth(statusLbl->sizePolicy().hasHeightForWidth());
        statusLbl->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(statusLbl, 1, 8, 1, 1);

        graphLbl = new QLabel(buttonFrame);
        graphLbl->setObjectName(QString::fromUtf8("graphLbl"));
        graphLbl->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(graphLbl, 1, 10, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        allBtn = new QPushButton(buttonFrame);
        allBtn->setObjectName(QString::fromUtf8("allBtn"));
        allBtn->setEnabled(true);
        allBtn->setMinimumSize(QSize(45, 0));
        allBtn->setMaximumSize(QSize(45, 16777215));

        horizontalLayout->addWidget(allBtn);

        noneBtn = new QPushButton(buttonFrame);
        noneBtn->setObjectName(QString::fromUtf8("noneBtn"));
        noneBtn->setEnabled(true);
        noneBtn->setMinimumSize(QSize(45, 0));
        noneBtn->setMaximumSize(QSize(45, 16777215));

        horizontalLayout->addWidget(noneBtn);


        gridLayout->addLayout(horizontalLayout, 0, 10, 1, 1);

        statusTxt = new QLabel(buttonFrame);
        statusTxt->setObjectName(QString::fromUtf8("statusTxt"));
        sizePolicy1.setHeightForWidth(statusTxt->sizePolicy().hasHeightForWidth());
        statusTxt->setSizePolicy(sizePolicy1);
        statusTxt->setWordWrap(true);

        gridLayout->addWidget(statusTxt, 0, 8, 1, 1);

        runBtn = new QPushButton(buttonFrame);
        runBtn->setObjectName(QString::fromUtf8("runBtn"));
        QSizePolicy sizePolicy3(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(runBtn->sizePolicy().hasHeightForWidth());
        runBtn->setSizePolicy(sizePolicy3);
        runBtn->setMinimumSize(QSize(52, 40));
        runBtn->setMaximumSize(QSize(52, 40));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8("../../../../../../../usr/share/linssid/linssid-start.png"), QSize(), QIcon::Normal, QIcon::Off);
        icon1.addFile(QString::fromUtf8("../../../../../../../usr/share/linssid/linssid-pause.png"), QSize(), QIcon::Normal, QIcon::On);
        runBtn->setIcon(icon1);
        runBtn->setIconSize(QSize(32, 32));
        runBtn->setCheckable(true);
        runBtn->setChecked(false);

        gridLayout->addWidget(runBtn, 0, 7, 1, 1);

        runLbl = new QLabel(buttonFrame);
        runLbl->setObjectName(QString::fromUtf8("runLbl"));
        runLbl->setBaseSize(QSize(52, 20));
        runLbl->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(runLbl, 1, 7, 1, 1);

        interfaceLbl = new QLabel(buttonFrame);
        interfaceLbl->setObjectName(QString::fromUtf8("interfaceLbl"));
        interfaceLbl->setMinimumSize(QSize(100, 20));
        interfaceLbl->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(interfaceLbl, 1, 6, 1, 1);

        interfaceCbx = new QComboBox(buttonFrame);
        interfaceCbx->addItem(QString());
        interfaceCbx->setObjectName(QString::fromUtf8("interfaceCbx"));
        interfaceCbx->setMinimumSize(QSize(100, 27));

        gridLayout->addWidget(interfaceCbx, 0, 6, 1, 1);

        linssidLogoMainframe = new QLabel(buttonFrame);
        linssidLogoMainframe->setObjectName(QString::fromUtf8("linssidLogoMainframe"));
        linssidLogoMainframe->setPixmap(QPixmap(QString::fromUtf8("../../../../../../../usr/share/pixmaps/linssid.png")));

        gridLayout->addWidget(linssidLogoMainframe, 0, 0, 2, 1);


        formLayout->setLayout(0, QFormLayout::SpanningRole, gridLayout);


        verticalLayout->addWidget(buttonFrame);

        splitter = new QSplitter(centralwidget);
        splitter->setObjectName(QString::fromUtf8("splitter"));
        sizePolicy.setHeightForWidth(splitter->sizePolicy().hasHeightForWidth());
        splitter->setSizePolicy(sizePolicy);
        splitter->setOrientation(Qt::Vertical);
        splitter->setOpaqueResize(true);
        mainTableWidget = new QTableWidget(splitter);
        mainTableWidget->setObjectName(QString::fromUtf8("mainTableWidget"));
        sizePolicy.setHeightForWidth(mainTableWidget->sizePolicy().hasHeightForWidth());
        mainTableWidget->setSizePolicy(sizePolicy);
        mainTableWidget->setMinimumSize(QSize(0, 150));
        mainTableWidget->setSortingEnabled(true);
        splitter->addWidget(mainTableWidget);
        mainTabWgt = new QTabWidget(splitter);
        mainTabWgt->setObjectName(QString::fromUtf8("mainTabWgt"));
        sizePolicy.setHeightForWidth(mainTabWgt->sizePolicy().hasHeightForWidth());
        mainTabWgt->setSizePolicy(sizePolicy);
        mainTabWgt->setMinimumSize(QSize(0, 150));
        timePlotTab = new QWidget();
        timePlotTab->setObjectName(QString::fromUtf8("timePlotTab"));
        sizePolicy.setHeightForWidth(timePlotTab->sizePolicy().hasHeightForWidth());
        timePlotTab->setSizePolicy(sizePolicy);
        verticalLayout_4 = new QVBoxLayout(timePlotTab);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        timePlot = new QwtPlot(timePlotTab);
        timePlot->setObjectName(QString::fromUtf8("timePlot"));

        verticalLayout_4->addWidget(timePlot);

        mainTabWgt->addTab(timePlotTab, QString());
        chan24Tab = new QWidget();
        chan24Tab->setObjectName(QString::fromUtf8("chan24Tab"));
        chan24Tab->setMinimumSize(QSize(0, 100));
        verticalLayout_2 = new QVBoxLayout(chan24Tab);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        chan24Plot = new QwtPlot(chan24Tab);
        chan24Plot->setObjectName(QString::fromUtf8("chan24Plot"));
        sizePolicy.setHeightForWidth(chan24Plot->sizePolicy().hasHeightForWidth());
        chan24Plot->setSizePolicy(sizePolicy);
        chan24Plot->setMinimumSize(QSize(0, 100));

        verticalLayout_2->addWidget(chan24Plot);

        mainTabWgt->addTab(chan24Tab, QString());
        chan5Tab = new QWidget();
        chan5Tab->setObjectName(QString::fromUtf8("chan5Tab"));
        sizePolicy.setHeightForWidth(chan5Tab->sizePolicy().hasHeightForWidth());
        chan5Tab->setSizePolicy(sizePolicy);
        verticalLayout_3 = new QVBoxLayout(chan5Tab);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        chan5Plot = new QwtPlot(chan5Tab);
        chan5Plot->setObjectName(QString::fromUtf8("chan5Plot"));

        verticalLayout_3->addWidget(chan5Plot);

        mainTabWgt->addTab(chan5Tab, QString());
        splitter->addWidget(mainTabWgt);

        verticalLayout->addWidget(splitter);

        mainForm->setCentralWidget(centralwidget);
        menubar = new QMenuBar(mainForm);
        menubar->setObjectName(QString::fromUtf8("menubar"));
        menubar->setGeometry(QRect(0, 0, 759, 30));
        menuFile = new QMenu(menubar);
        menuFile->setObjectName(QString::fromUtf8("menuFile"));
        menuView = new QMenu(menubar);
        menuView->setObjectName(QString::fromUtf8("menuView"));
        menuHelp = new QMenu(menubar);
        menuHelp->setObjectName(QString::fromUtf8("menuHelp"));
        mainForm->setMenuBar(menubar);
        statusbar = new QStatusBar(mainForm);
        statusbar->setObjectName(QString::fromUtf8("statusbar"));
        mainForm->setStatusBar(statusbar);

        menubar->addAction(menuFile->menuAction());
        menubar->addAction(menuView->menuAction());
        menubar->addAction(menuHelp->menuAction());
        menuFile->addAction(actionExport_to_NS1);
        menuFile->addSeparator();
        menuFile->addAction(actionPrefs);
        menuFile->addSeparator();
        menuFile->addAction(actionExit);
        menuView->addAction(actionPlot);
        menuView->addAction(actionSSID);
        menuView->addAction(actionMAC);
        menuView->addAction(actionChannel);
        menuView->addAction(actionMode);
        menuView->addAction(actionSecurity);
        menuView->addAction(actionPrivacy);
        menuView->addAction(actionCipher);
        menuView->addAction(actionFrequency);
        menuView->addAction(actionQuality);
        menuView->addAction(actionSignal);
        menuView->addAction(actionBW);
        menuView->addAction(actionVendor);
        menuView->addAction(actionType);
        menuView->addAction(actionMin_Signal);
        menuView->addAction(actionMax_Signal);
        menuView->addAction(actionCenChan);
        menuView->addAction(actionFirst_Seen);
        menuView->addAction(actionLast_Seen);
        menuView->addAction(actionProtocol);
        menuHelp->addAction(actionAbout);

        retranslateUi(mainForm);
        QObject::connect(actionExit, SIGNAL(triggered()), mainForm, SLOT(close()));

        mainTabWgt->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(mainForm);
    } // setupUi

    void retranslateUi(QMainWindow *mainForm)
    {
        mainForm->setWindowTitle(QCoreApplication::translate("mainForm", "LinSSID", nullptr));
        actionExport_to_NS1->setText(QCoreApplication::translate("mainForm", "&Export to NS1", nullptr));
        actionExit->setText(QCoreApplication::translate("mainForm", "E&xit", nullptr));
        actionSSID->setText(QCoreApplication::translate("mainForm", "&SSID", nullptr));
        actionChannel->setText(QCoreApplication::translate("mainForm", "&Channel", nullptr));
        actionMAC->setText(QCoreApplication::translate("mainForm", "&MAC", nullptr));
        actionMode->setText(QCoreApplication::translate("mainForm", "M&ode", nullptr));
        actionSecurity->setText(QCoreApplication::translate("mainForm", "S&ecurity", nullptr));
        actionPrivacy->setText(QCoreApplication::translate("mainForm", "P&rivacy", nullptr));
        actionCipher->setText(QCoreApplication::translate("mainForm", "C&ipher", nullptr));
        actionFrequency->setText(QCoreApplication::translate("mainForm", "&Frequency", nullptr));
        actionQuality->setText(QCoreApplication::translate("mainForm", "&Quality", nullptr));
        actionSignal->setText(QCoreApplication::translate("mainForm", "Si&gnal", nullptr));
        actionBW->setText(QCoreApplication::translate("mainForm", "&BW MHz", nullptr));
#if QT_CONFIG(tooltip)
        actionBW->setToolTip(QCoreApplication::translate("mainForm", "Max Bandwidth", nullptr));
#endif // QT_CONFIG(tooltip)
        actionVendor->setText(QCoreApplication::translate("mainForm", "&Vendor", nullptr));
        actionFirst->setText(QCoreApplication::translate("mainForm", "First", nullptr));
        actionLast->setText(QCoreApplication::translate("mainForm", "Last", nullptr));
        actionType->setText(QCoreApplication::translate("mainForm", "&Type", nullptr));
        actionAbout->setText(QCoreApplication::translate("mainForm", "&About", nullptr));
        actionCenChan->setText(QCoreApplication::translate("mainForm", "Cen Chan", nullptr));
        actionMin_Signal->setText(QCoreApplication::translate("mainForm", "Mi&n Signal", nullptr));
        actionMax_Signal->setText(QCoreApplication::translate("mainForm", "Ma&x Signal", nullptr));
        actionFirst_Seen->setText(QCoreApplication::translate("mainForm", "First Seen", nullptr));
        actionLast_Seen->setText(QCoreApplication::translate("mainForm", "&Last Seen", nullptr));
        actionPlot->setText(QCoreApplication::translate("mainForm", "&Plot", nullptr));
        actionPrefs->setText(QCoreApplication::translate("mainForm", "&Preferences...", nullptr));
        actionProtocol->setText(QCoreApplication::translate("mainForm", "Protocol", nullptr));
#if QT_CONFIG(tooltip)
        napTimeSlider->setToolTip(QCoreApplication::translate("mainForm", "Time between scans so your wireless interface can do something else", nullptr));
#endif // QT_CONFIG(tooltip)
        napTimeLbl->setText(QCoreApplication::translate("mainForm", "0 - nap time - 5", nullptr));
        statusLbl->setText(QCoreApplication::translate("mainForm", "Status", nullptr));
#if QT_CONFIG(tooltip)
        graphLbl->setToolTip(QCoreApplication::translate("mainForm", "Select or deselect all visible APs", nullptr));
#endif // QT_CONFIG(tooltip)
        graphLbl->setText(QCoreApplication::translate("mainForm", "Plot", nullptr));
#if QT_CONFIG(tooltip)
        allBtn->setToolTip(QCoreApplication::translate("mainForm", "Select all visible APs", nullptr));
#endif // QT_CONFIG(tooltip)
        allBtn->setText(QCoreApplication::translate("mainForm", "all", nullptr));
#if QT_CONFIG(tooltip)
        noneBtn->setToolTip(QCoreApplication::translate("mainForm", "Deselect all visible APs", nullptr));
#endif // QT_CONFIG(tooltip)
        noneBtn->setText(QCoreApplication::translate("mainForm", "none", nullptr));
        statusTxt->setText(QCoreApplication::translate("mainForm", "Paused", nullptr));
#if QT_CONFIG(tooltip)
        runBtn->setToolTip(QCoreApplication::translate("mainForm", "Start or stop run mode", nullptr));
#endif // QT_CONFIG(tooltip)
        runLbl->setText(QCoreApplication::translate("mainForm", "Run", nullptr));
        interfaceLbl->setText(QCoreApplication::translate("mainForm", "Interface", nullptr));
        interfaceCbx->setItemText(0, QString());

#if QT_CONFIG(tooltip)
        interfaceCbx->setToolTip(QCoreApplication::translate("mainForm", "Select a wireless interface if you have more than one", nullptr));
#endif // QT_CONFIG(tooltip)
        linssidLogoMainframe->setText(QString());
#if QT_CONFIG(tooltip)
        mainTabWgt->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        timePlotTab->setToolTip(QCoreApplication::translate("mainForm", "Signal strength over time", nullptr));
#endif // QT_CONFIG(tooltip)
        mainTabWgt->setTabText(mainTabWgt->indexOf(timePlotTab), QCoreApplication::translate("mainForm", "Time Graph", nullptr));
#if QT_CONFIG(tooltip)
        chan24Tab->setToolTip(QCoreApplication::translate("mainForm", "Signal strength by channel", nullptr));
#endif // QT_CONFIG(tooltip)
        mainTabWgt->setTabText(mainTabWgt->indexOf(chan24Tab), QCoreApplication::translate("mainForm", "2.4 GHz Channels", nullptr));
#if QT_CONFIG(tooltip)
        chan5Tab->setToolTip(QCoreApplication::translate("mainForm", "Signal strength by channel", nullptr));
#endif // QT_CONFIG(tooltip)
        mainTabWgt->setTabText(mainTabWgt->indexOf(chan5Tab), QCoreApplication::translate("mainForm", "5 GHz Channels", nullptr));
        menuFile->setTitle(QCoreApplication::translate("mainForm", "Fi&le", nullptr));
        menuView->setTitle(QCoreApplication::translate("mainForm", "&View", nullptr));
        menuHelp->setTitle(QCoreApplication::translate("mainForm", "Help", nullptr));
    } // retranslateUi

};

namespace Ui {
    class mainForm: public Ui_mainForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINFORM_H
