/********************************************************************************
** Form generated from reading UI file 'AboutBox.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ABOUTBOX_H
#define UI_ABOUTBOX_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>

QT_BEGIN_NAMESPACE

class Ui_aboutBox
{
public:
    QGridLayout *gridLayout;
    QLabel *aboutVersion;
    QSpacerItem *horizontalSpacer;
    QPushButton *aboutCloseBtn;
    QLabel *aboutLogoLabel;
    QLabel *aboutLabel;

    void setupUi(QDialog *aboutBox)
    {
        if (aboutBox->objectName().isEmpty())
            aboutBox->setObjectName(QString::fromUtf8("aboutBox"));
        aboutBox->resize(379, 387);
        QIcon icon;
        icon.addFile(QString::fromUtf8("../../../../../../../usr/share/pixmaps/linssid.png"), QSize(), QIcon::Normal, QIcon::Off);
        aboutBox->setWindowIcon(icon);
        aboutBox->setModal(true);
        gridLayout = new QGridLayout(aboutBox);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        aboutVersion = new QLabel(aboutBox);
        aboutVersion->setObjectName(QString::fromUtf8("aboutVersion"));

        gridLayout->addWidget(aboutVersion, 3, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(447, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 3, 1, 1, 1);

        aboutCloseBtn = new QPushButton(aboutBox);
        aboutCloseBtn->setObjectName(QString::fromUtf8("aboutCloseBtn"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(aboutCloseBtn->sizePolicy().hasHeightForWidth());
        aboutCloseBtn->setSizePolicy(sizePolicy);

        gridLayout->addWidget(aboutCloseBtn, 3, 2, 1, 1);

        aboutLogoLabel = new QLabel(aboutBox);
        aboutLogoLabel->setObjectName(QString::fromUtf8("aboutLogoLabel"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(aboutLogoLabel->sizePolicy().hasHeightForWidth());
        aboutLogoLabel->setSizePolicy(sizePolicy1);
        aboutLogoLabel->setMaximumSize(QSize(64, 64));
        aboutLogoLabel->setFrameShape(QFrame::StyledPanel);
        aboutLogoLabel->setText(QString::fromUtf8(""));
        aboutLogoLabel->setPixmap(QPixmap(QString::fromUtf8("../../../../../../../usr/share/pixmaps/linssid.png")));
        aboutLogoLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        gridLayout->addWidget(aboutLogoLabel, 0, 0, 1, 1);

        aboutLabel = new QLabel(aboutBox);
        aboutLabel->setObjectName(QString::fromUtf8("aboutLabel"));
        aboutLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        aboutLabel->setWordWrap(true);

        gridLayout->addWidget(aboutLabel, 1, 0, 1, 3);


        retranslateUi(aboutBox);
        QObject::connect(aboutCloseBtn, SIGNAL(clicked()), aboutBox, SLOT(close()));

        QMetaObject::connectSlotsByName(aboutBox);
    } // setupUi

    void retranslateUi(QDialog *aboutBox)
    {
        aboutBox->setWindowTitle(QCoreApplication::translate("aboutBox", "About linssid...", nullptr));
        aboutVersion->setText(QCoreApplication::translate("aboutBox", "Version:", nullptr));
        aboutCloseBtn->setText(QCoreApplication::translate("aboutBox", "Close", nullptr));
        aboutLabel->setText(QCoreApplication::translate("aboutBox", "LinSSID is authored by Warren Severin. It borrows from the graphic design ideas of the Windows program Inssider, but it is otherwise completely built from scratch.\n"
"\n"
"The LinSSID program is licensed under the terms of the GPL version 3. LinSSID version 2.2 and above are built using Qt5. LinSSID links to libraries of the Qwt project (http://qwt.sf.net). The LinSSID program also links to the Boost C++ libraries. The license to use these components is included in the program binary distribution.\n"
"\n"
"Hint: LinSSID will run faster when your interface is not connected to an attach point.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class aboutBox: public Ui_aboutBox {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ABOUTBOX_H
