/********************************************************************************
** Form generated from reading UI file 'prefsDialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFSDIALOG_H
#define UI_PREFSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>

QT_BEGIN_NAMESPACE

class Ui_prefsDialog
{
public:
    QGridLayout *gridLayout;
    QCheckBox *plotGridcbx;
    QLabel *dbMinlbl;
    QLabel *dbMaxlbl;
    QSpinBox *dbMaxsb;
    QSpinBox *dbMinsb;
    QLabel *plotGridlbl;
    QDialogButtonBox *buttonBox;
    QCheckBox *logDatacbx;
    QLabel *logoLbl;
    QLabel *logDatalbl;
    QLabel *fntSizeLbl;
    QComboBox *tblFntSizeSb;

    void setupUi(QDialog *prefsDialog)
    {
        if (prefsDialog->objectName().isEmpty())
            prefsDialog->setObjectName(QString::fromUtf8("prefsDialog"));
        prefsDialog->resize(328, 264);
        gridLayout = new QGridLayout(prefsDialog);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        plotGridcbx = new QCheckBox(prefsDialog);
        plotGridcbx->setObjectName(QString::fromUtf8("plotGridcbx"));
        plotGridcbx->setChecked(true);

        gridLayout->addWidget(plotGridcbx, 4, 2, 1, 1);

        dbMinlbl = new QLabel(prefsDialog);
        dbMinlbl->setObjectName(QString::fromUtf8("dbMinlbl"));

        gridLayout->addWidget(dbMinlbl, 2, 1, 1, 1);

        dbMaxlbl = new QLabel(prefsDialog);
        dbMaxlbl->setObjectName(QString::fromUtf8("dbMaxlbl"));

        gridLayout->addWidget(dbMaxlbl, 1, 1, 1, 1);

        dbMaxsb = new QSpinBox(prefsDialog);
        dbMaxsb->setObjectName(QString::fromUtf8("dbMaxsb"));
        dbMaxsb->setMinimum(-50);
        dbMaxsb->setMaximum(0);
        dbMaxsb->setSingleStep(10);
        dbMaxsb->setValue(-20);

        gridLayout->addWidget(dbMaxsb, 1, 2, 1, 1);

        dbMinsb = new QSpinBox(prefsDialog);
        dbMinsb->setObjectName(QString::fromUtf8("dbMinsb"));
        dbMinsb->setMinimum(-100);
        dbMinsb->setMaximum(-60);
        dbMinsb->setSingleStep(10);
        dbMinsb->setValue(-100);

        gridLayout->addWidget(dbMinsb, 2, 2, 1, 1);

        plotGridlbl = new QLabel(prefsDialog);
        plotGridlbl->setObjectName(QString::fromUtf8("plotGridlbl"));

        gridLayout->addWidget(plotGridlbl, 4, 1, 1, 1);

        buttonBox = new QDialogButtonBox(prefsDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 6, 2, 1, 1);

        logDatacbx = new QCheckBox(prefsDialog);
        logDatacbx->setObjectName(QString::fromUtf8("logDatacbx"));

        gridLayout->addWidget(logDatacbx, 5, 2, 1, 1);

        logoLbl = new QLabel(prefsDialog);
        logoLbl->setObjectName(QString::fromUtf8("logoLbl"));
        logoLbl->setPixmap(QPixmap(QString::fromUtf8("linssid48.png")));
        logoLbl->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(logoLbl, 6, 1, 1, 1);

        logDatalbl = new QLabel(prefsDialog);
        logDatalbl->setObjectName(QString::fromUtf8("logDatalbl"));

        gridLayout->addWidget(logDatalbl, 5, 1, 1, 1);

        fntSizeLbl = new QLabel(prefsDialog);
        fntSizeLbl->setObjectName(QString::fromUtf8("fntSizeLbl"));

        gridLayout->addWidget(fntSizeLbl, 0, 1, 1, 1);

        tblFntSizeSb = new QComboBox(prefsDialog);
        tblFntSizeSb->setObjectName(QString::fromUtf8("tblFntSizeSb"));

        gridLayout->addWidget(tblFntSizeSb, 0, 2, 1, 1);


        retranslateUi(prefsDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), prefsDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), prefsDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(prefsDialog);
    } // setupUi

    void retranslateUi(QDialog *prefsDialog)
    {
        prefsDialog->setWindowTitle(QCoreApplication::translate("prefsDialog", "Preferences", nullptr));
        dbMinlbl->setText(QCoreApplication::translate("prefsDialog", "Plot Min db", nullptr));
        dbMaxlbl->setText(QCoreApplication::translate("prefsDialog", "Plot Max db", nullptr));
        plotGridlbl->setText(QCoreApplication::translate("prefsDialog", "Show plot grid lines", nullptr));
#if QT_CONFIG(tooltip)
        logDatacbx->setToolTip(QCoreApplication::translate("prefsDialog", "<html><head/><body><p>Log data to file &quot;~/LinSSID.datalog&quot;</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        logDatacbx->setText(QString());
#if QT_CONFIG(tooltip)
        logDatalbl->setToolTip(QCoreApplication::translate("prefsDialog", "<html><head/><body><p>Log data to file &quot;~/LinSSID.datalog&quot;</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        logDatalbl->setText(QCoreApplication::translate("prefsDialog", "Log Data", nullptr));
        fntSizeLbl->setText(QCoreApplication::translate("prefsDialog", "Table font size", nullptr));
    } // retranslateUi

};

namespace Ui {
    class prefsDialog: public Ui_prefsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFSDIALOG_H
